X-Git-Url: https://git.xinqibao.xyz/dwm.git/blobdiff_plain/27b0595af72060d7cc406639b6c53a854f0a3590..338c0838580b32f1258a800392d93cf973baf1e6:/dwm.h?ds=sidebyside

diff --git a/dwm.h b/dwm.h
index 538018a..d795c84 100644
--- a/dwm.h
+++ b/dwm.h
@@ -41,23 +41,6 @@ enum { WMProtocols, WMDelete, WMState, WMLast };	/* default atoms */
 enum { CurNormal, CurResize, CurMove, CurLast };	/* cursor */
 enum { ColBorder, ColFG, ColBG, ColLast };		/* color */
 
-typedef struct {
-	int ascent;
-	int descent;
-	int height;
-	XFontSet set;
-	XFontStruct *xfont;
-} Fnt;
-
-typedef struct {
-	int x, y, w, h;
-	unsigned long norm[ColLast];
-	unsigned long sel[ColLast];
-	Drawable drawable;
-	Fnt font;
-	GC gc;
-} DC; /* draw context */
-
 typedef struct Client Client;
 struct Client {
 	char name[256];
@@ -67,7 +50,7 @@ struct Client {
 	int minax, minay, maxax, maxay;
 	long flags; 
 	unsigned int border;
-	Bool isbanned, isfixed, ismax, isversatile;
+	Bool isbanned, isfixed, ismax, isfloating;
 	Bool *tags;
 	Client *next;
 	Client *prev;
@@ -75,6 +58,21 @@ struct Client {
 	Window win;
 };
 
+typedef struct {
+	int x, y, w, h;
+	unsigned long norm[ColLast];
+	unsigned long sel[ColLast];
+	Drawable drawable;
+	GC gc;
+	struct {
+		int ascent;
+		int descent;
+		int height;
+		XFontSet set;
+		XFontStruct *xfont;
+	} font;
+} DC; /* draw context */
+
 typedef struct {
 	const char *symbol;
 	void (*arrange)(void);
@@ -105,7 +103,7 @@ extern void killclient(const char *arg);		/* kill c nicely */
 extern void manage(Window w, XWindowAttributes *wa);	/* manage new client */
 extern void resize(Client *c, int x, int y,
 		int w, int h, Bool sizehints);	/* resize with given coordinates c*/
-extern void toggleversatile(const char *arg);	/* toggles focused client between versatile/and non-versatile state */
+extern void togglefloating(const char *arg);	/* toggles focused client between floating/tiled state */
 extern void updatesizehints(Client *c);		/* update the size hint variables of c */
 extern void updatetitle(Client *c);		/* update the name of c */
 extern void unmanage(Client *c);		/* destroy c */
@@ -119,6 +117,7 @@ extern unsigned int textw(const char *text);	/* return the width of text in px*/
 extern void grabkeys(void);			/* grab all keys defined in config.h */
 
 /* layout.c */
+extern void floating(void);			/* arranges all windows floating */
 extern void focusclient(const char *arg);	/* focuses next(1)/previous(-1) visible client */
 extern void incmasterw(const char *arg);	/* increments the master width with arg's index value */
 extern void incnmaster(const char *arg);	/* increments nmaster with arg's index value */
@@ -126,8 +125,7 @@ extern void initlayouts(void);			/* initialize layout array */
 extern Client *nexttiled(Client *c);		/* returns tiled successor of c */
 extern void restack(void);			/* restores z layers of all clients */
 extern void setlayout(const char *arg);		/* sets layout, -1 toggles */
-extern void togglemax(const char *arg);		/* toggles maximization of versatile client */
-extern void versatile(void);			/* arranges all windows versatile */
+extern void togglemax(const char *arg);		/* toggles maximization of floating client */
 extern void zoom(const char *arg);		/* zooms the focused client to master area, arg is ignored */
 
 /* main.c */